# Google Image Downloader

這是一個用於從 Google 搜尋下載圖片的 Python 模組。


## 安裝

使用 pip 安裝：

```sh
pip install piggaga_models



```python
from piggaga_models import download_google_images

download_google_images("query", num_images)


- 下載指定搜尋詞的圖片
- 指定下載圖片的數量


- 豬嘎嘎 (@piggaga)
